migrate

Function migrate 

pub async fn migrate(client: &Client) -> Result<(), ClickhouseUtilsError>
Run the migrations in the migrations folder.

  • Migration are run in alphabetical order.
  • If the migration has changed, will halt with an error.
  • If the migration has been run before, it will be skipped.

We MD5 the content of the migration file to detect changes. A table __migrations is created and used to track the migrations that have been run.